Versions
========

0.0.1 (2020-03-24)
========
- Create package setup procedure
- Describe usage in readme file
- Include HTTP session unittests
- Introduce 'uyaml' package
- Cover project with unittests
- Implement URLs support
- Implement HTTP responses
- Implement HTTP sessions
- Present initial 'urequest' package
